@@ -47,7 +47,6 @@ from pylav.constants.config import (
     MANAGED_NODE_SPOTIFY_CLIENT_SECRET,
     MANAGED_NODE_SPOTIFY_COUNTRY_CODE,
     MANAGED_NODE_YANDEX_MUSIC_ACCESS_TOKEN,
-    PREFER_PARTIAL_TRACKS,
     REDIS_FULL_ADDRESS_RESPONSE_CACHE,
     TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS_DAYS,
     TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS,
@@ -70,7 +69,7 @@ from pylav.extension.radio import RadioBrowser
 from pylav.helpers.singleton import SingletonCallable, SingletonClass
 from pylav.helpers.time import get_now_utc, get_tz_utc
 from pylav.logging import getLogger
-from pylav.nodes.api.responses.rest_api import LoadTrackResponses
+from pylav.nodes.api.responses.rest_api import LoadFailed, LoadTrackResponses, NoMatches
 from pylav.nodes.api.responses.route_planner import Status as RoutePlannerStatus
 from pylav.nodes.api.responses.track import Track as TrackObject
 from pylav.nodes.manager import NodeManager
@@ -96,6 +95,7 @@ from pylav.storage.models.node.real import Node as RealNode
 from pylav.storage.models.player.state import PlayerState
 from pylav.type_hints.bot import DISCORD_BOT_TYPE, DISCORD_COG_TYPE, DISCORD_CONTEXT_TYPE, DISCORD_INTERACTION_TYPE
 from pylav.utils.aiohttp_postgres_cache import PostgresCacheBackend
+from pylav.utils.localtracks import LocalTrackCache
 
 try:
     from redbot.core.i18n import Translator
@@ -148,6 +148,7 @@ class Client(metaclass=SingletonClass):
     __old_process_command_method: Callable = None
     __old_get_context: Callable = None
     _initiated = False
+    __local_tracks_cache: LocalTrackCache
 
     def __init__(
         self,
@@ -227,6 +228,7 @@ class Client(metaclass=SingletonClass):
             self._player_state_db_manager = PlayerStateController(self)
             self._player_config_manager = PlayerConfigController(self)
             self._equalizer_config_manager = EqualizerController(self)
+
             self._flowery_api = FloweryAPI(self)
             self._radio_manager = RadioBrowser(self)
             self._m3u8parser = M3UParser(self)
@@ -412,6 +414,10 @@ class Client(metaclass=SingletonClass):
     def bot_id(self) -> str:
         return self._user_id
 
+    @property
+    def local_tracks_cache(self) -> LocalTrackCache:
+        return self.__local_tracks_cache
+
     @SingletonCallable.run_once_async
     async def initialize(self) -> None:
         try:
@@ -454,6 +460,7 @@ class Client(metaclass=SingletonClass):
                 LOGGER.info("Settings folder: %s", config_folder)
                 LOGGER.info("Localtracks folder: %s", localtrack_folder)
                 self._config_folder = aiopath.AsyncPath(config_folder)
+                self.__local_tracks_cache = LocalTrackCache(self, localtrack_folder)
                 bundled_node_config = self._node_config_manager.bundled_node_config()
                 spotify_client_id, spotify_client_secret = await self._initialize_yaml_config(
                     bundled_node_config,
@@ -484,6 +491,7 @@ class Client(metaclass=SingletonClass):
                 await self._run_post_init_jobs(java_path)
                 self.ready.set()
                 LOGGER.info("PyLav is ready")
+                await self.__local_tracks_cache.initialize()
 
     async def _initialise_modules(self):
         await self._lib_config_manager.initialize()
@@ -603,6 +611,10 @@ class Client(metaclass=SingletonClass):
 
     async def _add_scheduler_job_external_playlists(self):
         next_execution_update_external_playlists = await self._config.fetch_next_execution_update_external_playlists()
+        if next_execution_update_external_playlists >= (
+            alt_next := (get_now_utc() + datetime.timedelta(days=TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS_DAYS))
+        ):
+            next_execution_update_external_playlists = alt_next
         self._scheduler.add_job(
             self.playlist_db_manager.update_external_playlists,
             trigger="interval",
@@ -624,6 +636,10 @@ class Client(metaclass=SingletonClass):
         next_execution_update_bundled_external_playlists = (
             await self._config.fetch_next_execution_update_bundled_external_playlists()
         )
+        if next_execution_update_bundled_external_playlists >= (
+            alt_next := (get_now_utc() + datetime.timedelta(days=TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS_DAYS))
+        ):
+            next_execution_update_bundled_external_playlists = alt_next
         self._scheduler.add_job(
             self.playlist_db_manager.update_bundled_external_playlists,
             trigger="interval",
@@ -643,6 +659,10 @@ class Client(metaclass=SingletonClass):
 
     async def _add_scheduler_job_bundled_playlist(self):
         next_execution_update_bundled_playlists = await self._config.fetch_next_execution_update_bundled_playlists()
+        if next_execution_update_bundled_playlists >= (
+            alt_next := (get_now_utc() + datetime.timedelta(days=TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS))
+        ):
+            next_execution_update_bundled_playlists = alt_next
         self._scheduler.add_job(
             self.playlist_db_manager.update_bundled_playlists,
             trigger="interval",
@@ -1037,11 +1057,13 @@ class Client(metaclass=SingletonClass):
                     self.bot.remove_listener(self.on_pylav_ready, name="on_ready")
                     self.bot.remove_listener(self.on_pylav_resumed, name="on_resumed")
                     self._shutting_down = True
+
                     self.ready.clear()
                     try:
                         Client._instances.clear()
                         SingletonCallable.reset()
                         self._initiated = False
+                        await self.__local_tracks_cache.shutdown()
                         await self.player_manager.save_all_players()
                         await self.player_manager.shutdown()
                         await self._node_manager.close()
@@ -1224,6 +1246,7 @@ class Client(metaclass=SingletonClass):
         """
         if not self.node_manager.available_nodes:
             raise NoNodeAvailableException("There are no available nodes!")
+
         node = await self.node_manager.find_best_node(
             feature=query.requires_capability,
             region=player.region if player else None,
@@ -1245,7 +1268,6 @@ class Client(metaclass=SingletonClass):
         player: Player | None = None,
         bypass_cache: bool = False,
         enqueue: bool = True,
-        partial: bool = PREFER_PARTIAL_TRACKS,
     ) -> tuple[list[Track], int, list[Query]]:  # sourcery no-metrics
         """High level interface to get and return all tracks for a list of queries.
 
@@ -1265,8 +1287,6 @@ class Client(metaclass=SingletonClass):
         enqueue : `bool`, optional
             Whether to enqueue the tracks as needed
             while try are processed so users dont sit waiting for the bot to finish.
-        partial : `bool`, optional
-            Whether to return partial results
 
         Returns
         -------
@@ -1282,21 +1302,23 @@ class Client(metaclass=SingletonClass):
         queries_failed = []
         track_count = 0
         for query in queries:
-            track_count = await self._get_tracks_single_query(
-                bypass_cache,
-                enqueue,
-                player,
-                queries_failed,
-                query,
-                requester,
-                successful_tracks,
-                track_count,
-                query.is_partial if partial is None else partial,
-            )
+            try:
+                track_count = await self._get_tracks_single_query(
+                    bypass_cache,
+                    enqueue,
+                    player,
+                    queries_failed,
+                    query,
+                    requester,
+                    successful_tracks,
+                    track_count,
+                )
+            except Exception:
+                queries_failed.append(query)
         return successful_tracks, track_count, queries_failed
 
     async def _get_tracks_single_query(
-        self, bypass_cache, enqueue, player, queries_failed, query, requester, successful_tracks, track_count, partial
+        self, bypass_cache, enqueue, player, queries_failed, query, requester, successful_tracks, track_count
     ):
         async for sub_query in self._yield_recursive_queries(query):
             node = await self.node_manager.find_best_node(
@@ -1308,11 +1330,7 @@ class Client(metaclass=SingletonClass):
                 queries_failed.append(sub_query)
                 continue
             await self._get_tracks_play_or_enqueue(enqueue, player, requester, successful_tracks)
-            if partial and sub_query.is_single:
-                track_count = await self._get_tracks_partial_single(
-                    enqueue, node, player, requester, sub_query, successful_tracks, track_count
-                )
-            elif sub_query.is_search or sub_query.is_single:
+            if sub_query.is_search or sub_query.is_single:
                 track_count = await self._get_tracks_search_or_single(
                     bypass_cache,
                     node,
@@ -1322,7 +1340,6 @@ class Client(metaclass=SingletonClass):
                     sub_query,
                     successful_tracks,
                     track_count,
-                    partial,
                 )
             elif (
                 (sub_query.is_playlist or sub_query.is_album)
@@ -1342,34 +1359,13 @@ class Client(metaclass=SingletonClass):
                 )
             elif (sub_query.is_local or sub_query.is_custom_playlist) and sub_query.is_album:
                 track_count = await self._get_tracks_local_album(
-                    enqueue, node, player, queries_failed, requester, sub_query, successful_tracks, track_count, partial
+                    enqueue, node, player, queries_failed, requester, sub_query, successful_tracks, track_count
                 )
             else:
                 queries_failed.append(sub_query)
                 LOGGER.warning("Unhandled query: %s, %s", sub_query.to_dict(), sub_query.query_identifier)
         return track_count
 
-    async def _get_tracks_partial_single(
-        self, enqueue, node, player, requester, sub_query, successful_tracks, track_count
-    ):
-        track_count += 1
-        if cached_query := await self.node_manager.client.query_cache_manager.fetch_query(sub_query):
-            data = (await cached_query.fetch_tracks())[0]
-        else:
-            data = None
-        successful_tracks.append(
-            await Track.build_track(
-                data=data,
-                node=node,
-                query=sub_query,
-                requester=requester.id,
-            )
-        )
-        if enqueue and successful_tracks and not player.is_playing and not player.paused:
-            track = successful_tracks.pop()
-            await player.play(track, await track.query(), requester)
-        return track_count
-
     @staticmethod
     async def _get_tracks_play_or_enqueue(enqueue, player, requester, successful_tracks):
         # Query tracks as the queue builds as this may be a slow operation
@@ -1383,25 +1379,22 @@ class Client(metaclass=SingletonClass):
             await player.add(requester.id, track, query=await track.query())
 
     async def _get_tracks_local_album(
-        self, enqueue, node, player, queries_failed, requester, sub_query, successful_tracks, track_count, partial
+        self,
+        enqueue,
+        node,
+        player,
+        queries_failed,
+        requester,
+        sub_query,
+        successful_tracks,
+        track_count,
     ):
         yielded = False
         async for local_track in sub_query.get_all_tracks_in_folder():
             yielded = True
-            if partial:
-                track_count += 1
-                successful_tracks.append(
-                    await Track.build_track(
-                        data=None,
-                        node=node,
-                        query=local_track,
-                        requester=requester.id,
-                    )
-                )
-                continue
             response = await self._get_tracks(player=player, query=local_track, first=True, bypass_cache=True)
-            if isinstance(response, HTTPException):
-                queries_failed.append(sub_query)
+            if isinstance(response, (HTTPException, NoMatches, LoadFailed)):
+                queries_failed.append(local_track)
                 continue
             if __ := response.tracks[0].encoded:
                 track_count += 1
@@ -1434,7 +1427,7 @@ class Client(metaclass=SingletonClass):
         track_count,
     ):
         response = await self._get_tracks(player=player, query=sub_query, bypass_cache=bypass_cache)
-        if isinstance(response, HTTPException):
+        if isinstance(response, (HTTPException, NoMatches, LoadFailed)):
             queries_failed.append(sub_query)
             return track_count
         track_list = response.tracks
@@ -1458,16 +1451,14 @@ class Client(metaclass=SingletonClass):
         return track_count
 
     async def _get_tracks_search_or_single(
-        self, bypass_cache, node, player, queries_failed, requester, sub_query, successful_tracks, track_count, partial
+        self, bypass_cache, node, player, queries_failed, requester, sub_query, successful_tracks, track_count
     ):
         response = await self._get_tracks(player=player, query=sub_query, first=True, bypass_cache=bypass_cache)
-        if isinstance(response, HTTPException):
+        if isinstance(response, (HTTPException, NoMatches, LoadFailed)):
             queries_failed.append(sub_query)
             return track_count
-        track_b64 = response.tracks[0].encoded
-        if not track_b64:
-            queries_failed.append(sub_query)
-        if track_b64:
+
+        if response.tracks:
             track_count += 1
             new_query = await Query.from_string(response.tracks[0].info.uri)
             new_query.merge(sub_query, start_time=True)
@@ -1479,6 +1470,8 @@ class Client(metaclass=SingletonClass):
                     requester=requester.id,
                 )
             )
+        else:
+            queries_failed.append(sub_query)
         return track_count
 
     @staticmethod
@@ -1562,7 +1555,7 @@ class Client(metaclass=SingletonClass):
                 response = await self.search_query(
                     subquery, bypass_cache=bypass_cache, fullsearch=fullsearch, region=region
                 )
-                if response is None or not response.tracks:
+                if (not response) or (not response.tracks):
                     continue
                 if subquery.is_playlist or subquery.is_album:
                     playlist_name = response.playlistInfo.name if response.playlistInfo else ""
@@ -1613,8 +1606,6 @@ class Client(metaclass=SingletonClass):
             if a Search query is passed wether to returrn a list of tracks instead of the first.
         region : `str`, optional
             The region to search in.
-        player : `Player`, optional
-            The player to use for enqueuing tracks.
         """
         node = await self.node_manager.find_best_node(region=region, feature=query.requires_capability)
         if node is None:
